'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const core = require('./core-f42eff8b.js');
const coordinate = require('./coordinate-1ab3deeb.js');
const mapBase = require('./map-base-f125015f.js');

const RLMap = class {
    constructor(hostRef) {
        core.registerInstance(this, hostRef);
        /**
         * The array of MapElements currently being displayed.  Created from the
         * `elements` Prop with additional internal information added.
         */
        this.processedElements = [];
        /**
         * The original scale factor used to size the SVG so it fits into the SVG and
         * covers the entire SVG.
         */
        this.initialScale = 1;
        /**
         * The current state of the Map.
         */
        this.state = mapBase.STATES.NORMAL;
        /**
         * Flag indicating if the map image has loaded or not.
         */
        this.imageLoaded = false;
        /**
         * The current size of the SVG element used to display the map.
         */
        this.size = { width: 1, height: 1 };
        /**
         * The factor by which the Map contents are changed to fit within the SVG.
         */
        this.svgScale = 1;
        /**
         * The x,y translation applied to move the map contents within the bounds of
         * the SVG.
         */
        this.svgTransform = new coordinate.Coordinate(0, 0);
        /**
         *  The maximum scale factor.
         */
        this.maxScale = mapBase.DEFAULT_MAX_SCALE;
        /**
         * The minimum scale factor.
         */
        this.minScale = mapBase.DEFAULT_MIN_SCALE;
        this.elementDeselected = core.createEvent(this, "elementDeselected", 7);
        this.elementSelected = core.createEvent(this, "elementSelected", 7);
    }
    onActiveElementIdChanged() {
        if (this.processedElements.length > 0) {
            this._setActiveElement(this.processedElements.find(i => i.id === this.activeElementId), false);
        }
    }
    onMapImageChanged() {
        if (this.mapImage === undefined) {
            return;
        }
        const img = new Image();
        img.src = this.mapImage;
        this.imageLoaded = false;
        img.onload = () => {
            this.imageLoaded = true;
            if (this.imgSize &&
                this.imgSize.width === img.width &&
                this.imgSize.height === img.height) {
                return;
            }
            this.imgSize = { width: img.width, height: img.height };
            this.computeScale();
            this.limits = this.computeLimits();
        };
    }
    /**
     * Handle when the list of specified elements changes.
     */
    onElementsChanged() {
        // if (this.elements !== undefined) {
        this.processedElements = mapBase.parseElements(this.elements);
        // }
    }
    componentDidLoad() {
        this.onMapImageChanged();
        this.onElementsChanged();
        this.onResize();
    }
    /**
     * Handles when the user triggers a touch/down event to start interaction with
     * the map.
     * @param e The triggering event.
     */
    onGestureDown(e) {
        this.start = this.last = mapBase.coordinateFromEvent(e, this.root);
        if (this.state === mapBase.STATES.NORMAL) {
            this.state = mapBase.STATES.GESTURE_DOWN;
        }
        // Get the ID of the event target, if it is the correct type.
        const id = mapBase.getTargetId(e.target);
        if (id !== undefined) {
            this.targetElement = this.processedElements.find(i => i.id === id);
        }
    }
    /**
     * Handles when the user triggers a movement event.
     * @param e The triggering event.
     */
    onGestureMove(e) {
        if (this.state === mapBase.STATES.NORMAL) {
            return;
        }
        // Convert the coordinate to SVG coordinate space.
        const point = mapBase.coordinateFromEvent(e, this.root);
        switch (this.state) {
            case mapBase.STATES.GESTURE_DOWN:
                const dist = coordinate.Coordinate.squareDistance(this.start, point);
                if (dist > mapBase.HYSTERESIS) {
                    this.state = mapBase.STATES.DRAGGING;
                }
                break;
            case mapBase.STATES.DRAGGING:
                if (this.limits !== undefined) {
                    const delta = coordinate.Coordinate.difference(point, this.last);
                    this.svgTransform = coordinate.Coordinate.sum(this.svgTransform, delta).limit(this.limits).round();
                }
                break;
            default:
        }
        this.last = point;
    }
    /**
     * Handles when the user ends their interaction with the Map.
     * @param e The triggering event.
     */
    onGestureUp(e) {
        const point = mapBase.coordinateFromEvent(e, this.root);
        switch (this.state) {
            case mapBase.STATES.DRAGGING:
                if (this.limits !== undefined) {
                    const delta = coordinate.Coordinate.difference(point, this.last);
                    this.svgTransform = coordinate.Coordinate.sum(this.svgTransform, delta).limit(this.limits).round();
                }
                break;
            case mapBase.STATES.GESTURE_DOWN:
                if (this.targetElement) {
                    if (this.targetElement !== this.activeElement && this.targetElement.clickable) {
                        this._setActiveElement(this.targetElement);
                        this.targetElement = undefined;
                    }
                }
                else {
                    if (this.activeElement) {
                        this.elementDeselected.emit(this.activeElement);
                        this._clearActiveElement();
                    }
                }
                break;
            default:
        }
        this.state = mapBase.STATES.NORMAL;
    }
    /**
     * Handles when the user leaves the bounds of the Map entirely.
     * @param e The triggering event.
     */
    onMouseLeave(e) {
        if (this.state === mapBase.STATES.DRAGGING ||
            this.state === mapBase.STATES.GESTURE_DOWN) {
            this.state = mapBase.STATES.NORMAL;
            const point = mapBase.coordinateFromEvent(e, this.root);
            if (this.state === mapBase.STATES.DRAGGING && this.limits !== undefined) {
                const delta = coordinate.Coordinate.difference(point, this.last);
                this.svgTransform = coordinate.Coordinate.sum(this.svgTransform, delta).limit(this.limits).round();
                this.state = mapBase.STATES.NORMAL;
            }
        }
    }
    /**
     * Handles when the user performs a resize action.
     */
    onResize() {
        clearTimeout(this.resizeDebounce);
        this.resizeDebounce = setTimeout(_ => {
            // Use a 150ms delay to debounce multiple resize calls and effectively
            // perform the resize action only when the user is 'done' resizing.
            this.computeSvgSize();
            this.computeScale();
            this.limits = this.computeLimits();
            this.svgTransform = this.svgTransform.clone().limit(this.limits);
        }, 150);
    }
    /**
     * Handles when the user performs a mouse wheen event.  The Map will be zoomed
     * in or out depending on the direction of the wheel.
     *
     * @param e The triggering event.
     */
    onWheel(e) {
        const oldPos = this.toSvgSpace(new coordinate.Coordinate(e.clientX, e.clientY));
        if (e.deltaY < 0) {
            if (this.svgScale * 1.05263157895 < this.initialScale * this.maxScale) {
                this.svgScale *= 1.05263157895;
            }
        }
        else {
            if (this.svgScale * 0.95 > this.initialScale * this.minScale) {
                this.svgScale *= 0.95;
            }
        }
        this.limits = this.computeLimits();
        const newPos = this.toSvgSpace(new coordinate.Coordinate(e.clientX, e.clientY));
        const delta = coordinate.Coordinate.difference(newPos, oldPos).scale(this.svgScale);
        this.svgTransform.translate(delta).limit(this.limits).round();
    }
    onEnter(e) {
        if (e.key === 'enter' && e.target && e.target instanceof SVGElement &&
            (e.target.classList.contains('rl-map-polygon') ||
                e.target.classList.contains('rl-map-marker'))) {
            const id = Number(e.target.id);
            const el = this.processedElements.find(i => i.id === id);
            this._setActiveElement(el);
        }
    }
    /**
     * Clears the currently active element.
     */
    _clearActiveElement() {
        if (this.activeElement) {
            this.activeElement.active = false;
        }
        this.activeElement = undefined;
    }
    /**
     * Updates the limits used to restrict the how far the SVG transform can be
     * moved keeping the map from being panning beyond the edge of the image.
     */
    computeLimits() {
        const { imgSize, size } = this;
        if (imgSize !== undefined) {
            return mapBase.computeLimits(imgSize, size, this.svgScale);
        }
        else {
            return new DOMRect(0, 0, 1, 1);
        }
    }
    /**
     * Computes the scale factor needed to resize the full map image to be as
     * large as possible, and cropping it vertically/horizontally so no empty
     * space exists if the container has different aspect from the image. This is
     * like CSS `background-size: cover` or SVG `aspectRatio xMidYMid slice`.
     */
    computeScale() {
        const { imgSize, size } = this;
        if (imgSize === undefined) {
            this.svgScale = this.initialScale = 1;
        }
        else {
            this.svgScale = this.initialScale =
                Math.max(size.width / imgSize.width, size.height / imgSize.height);
        }
    }
    /**
     * Determines the current size of the SVG element serving as the container
     * for the entire map.
     */
    computeSvgSize() {
        const root = this.root.querySelector('svg');
        const rect = root && root.getBoundingClientRect();
        if (rect !== null) {
            this.size = { width: rect.width, height: rect.height };
        }
    }
    /**
     * Sets the currently active element of the Map.
     *
     * @param el The Element that will be set as the active element.
     */
    _setActiveElement(el, shouldEmit = true) {
        if (!el || (this.activeElement && el.id === this.activeElement.id)) {
            return;
        }
        this._clearActiveElement();
        this.activeElement = el;
        this.activeElement.active = true;
        // Emit an event with the original (un-parsed) element as the new 'active'
        // element.  Don't emit an event if the flag is set.
        if (shouldEmit) {
            this.elementSelected.emit(this.elements[this.activeElement.id]);
        }
    }
    /**
     * Scales a given `Coordinate` by the inverse of the current `svgScale`.
     * Returns a new `Coordinate` with its values scaled and rounded.
     * @param c A `Coordinate` scale.
     */
    toSvgScale(c) {
        return c.clone().scale(1 / this.svgScale).round();
    }
    /**
     * Converts a given `Coordinate` object in screen coordinate space to SVG
     * coordinate space.
     * @param c A `Coordinate` to convert to SVG coordinate space.
     */
    toSvgSpace(c) {
        return coordinate.Coordinate.difference(this.toSvgScale(c), this.toSvgScale(this.svgTransform));
    }
    hostData() {
        return {
            class: {
                'rl-map': true,
                'rl-map--loaded': this.imageLoaded,
            },
        };
    }
    __stencil_render() {
        const m = [
            this.svgScale, 0, 0, this.svgScale,
            this.svgTransform.x,
            this.svgTransform.y,
        ];
        const matrix = 'matrix(' + m.join(',') + ')';
        return (core.h("svg", { class: "rl-svg" }, core.h("g", { transform: matrix }, core.h("image", { xlinkHref: this.mapImage !== undefined ? this.mapImage : undefined }), this.processedElements.map(el => el.render()))));
    }
    get root() { return core.getElement(this); }
    static get watchers() { return {
        "activeElementId": ["onActiveElementIdChanged"],
        "mapImage": ["onMapImageChanged"],
        "elements": ["onElementsChanged"]
    }; }
    render() { return core.h(core.Host, this.hostData(), this.__stencil_render()); }
    static get style() { return "\@-webkit-keyframes fade-in {\n  0% {\n    opacity: 0;\n  }\n  100% {\n    opacity: 1;\n  }\n}\n\@keyframes fade-in {\n  0% {\n    opacity: 0;\n  }\n  100% {\n    opacity: 1;\n  }\n}\n.rl-map {\n  display: inline-block;\n  width: 100%;\n  height: 100%;\n  opacity: 0;\n  overflow: hidden;\n}\n.rl-map--loaded {\n  opacity: 1;\n  -webkit-animation: fade-in 180ms ease-in;\n  animation: fade-in 180ms ease-in;\n}\n\n.rl-svg {\n  width: 100%;\n  height: 100%;\n}\n.rl-svg__marker:focus rect {\n  outline: none;\n  fill: var(--rl-svg__focus-fill, rgba(255, 255, 83, 0.3));\n}\n.rl-svg__marker--clickable:hover rect {\n  outline: none;\n  fill: var(--rl-svg__focus-fill, rgba(255, 255, 83, 0.3));\n  cursor: pointer;\n}\n.rl-svg__marker text {\n  font-size: var(--rl-svg__text-size, 48px);\n  -webkit-user-select: none;\n  -moz-user-select: none;\n  -ms-user-select: none;\n  user-select: none;\n}\n.rl-svg__polygon {\n  fill: var(--rl-svg__polygon-fill, rgba(0, 76, 155, 0.6));\n  stroke: var(--rl-svg__polygon-stroke, #004c9b);\n  stroke-width: var(--rl-svg__polygon-stroke--width, 2);\n}\n.rl-svg__polygon:focus {\n  outline: none;\n  fill: var(--rl-svg__focus-fill, rgba(255, 255, 83, 0.3));\n}\n.rl-svg__polygon--activated {\n  outline: none;\n  stroke: var(--rl-svg__active-stroke, #c7ab00);\n  stroke-width: var(--rl-svg__active-stroke--width, 4);\n  outline: none;\n  fill: var(--rl-svg__focus-fill, rgba(255, 255, 83, 0.3));\n}\n.rl-svg__polygon:hover {\n  outline: none;\n  fill: var(--rl-svg__focus-fill, rgba(255, 255, 83, 0.3));\n  cursor: pointer;\n}\n.rl-svg__polygon-outline {\n  fill: none;\n  stroke: var(--rl-svg__active-stroke, #c7ab00);\n  stroke-width: var(--rl-svg__active-stroke--width, 4);\n}\n.rl-svg__polygon path {\n  outline: none;\n}\n.rl-svg__rect {\n  fill: none;\n  stroke: none;\n}\n.rl-svg__rect--activated {\n  outline: none;\n  stroke: var(--rl-svg__active-stroke, #c7ab00);\n  stroke-width: var(--rl-svg__active-stroke--width, 4);\n}\n.rl-svg__symbol {\n  fill: var(--rl-svg__symbol-fill, rgba(0, 76, 155, 0.6));\n  stroke: var(--rl-svg__symbol-stroke, #004c9b);\n  stroke-width: var(--rl-svg__symbol-stroke--width, 1);\n  fill-rule: evenodd;\n}\n.rl-svg__symbol--alt {\n  fill: var(--rl-svg__symbol-fill--alt, rgba(255, 255, 83, 0.5));\n  stroke: var(--rl-svg__symbol-stroke--alt, #c7ab00);\n}"; }
};

exports.rl_map = RLMap;
